@@ -13,7 +13,7 @@ from materialgirl import Materializer
 from materialgirl.storage.redis import RedisStorage
 import tornado
 
-from holmes.handlers.worker import WorkerHandler, WorkersHandler, WorkersInfoHandler
+from holmes.handlers.worker import WorkersHandler, WorkersInfoHandler
 from holmes.handlers.worker_state import WorkerStateHandler
 from holmes.handlers.page import (
     PageHandler, PageReviewsHandler, PageViolationsPerDayHandler, NextJobHandler
@@ -27,9 +27,7 @@ from holmes.handlers.review import (
 from holmes.handlers.domains import (
     DomainsHandler, DomainDetailsHandler, DomainViolationsPerDayHandler,
     DomainReviewsHandler, DomainsChangeStatusHandler, DomainsFullDataHandler,
-    DomainPageCountHandler, DomainReviewCountHandler, DomainViolationCountHandler,
-    DomainErrorPercentageHandler, DomainResponseTimeAvgHandler, DomainGroupedViolationsHandler,
-    DomainTopCategoryViolationsHandler
+    DomainGroupedViolationsHandler, DomainTopCategoryViolationsHandler
 )
 from holmes.handlers.search import (
     SearchHandler
@@ -47,6 +45,7 @@ from holmes.models import Key
 from holmes.models import KeysCategory
 from holmes.cache import Cache
 from holmes import __version__
+from holmes.handlers import BaseHandler
 
 
 def main():
@@ -54,7 +53,7 @@ def main():
     HolmesApiServer.run()
 
 
-class VersionHandler(tornado.web.RequestHandler):
+class VersionHandler(BaseHandler):
     def get(self):
         self.write(__version__)
 
@@ -85,7 +84,6 @@ class HolmesApiServer(Server):
             (r'/last-reviews/?', LastReviewsHandler),
             (r'/workers/?', WorkersHandler),
             (r'/workers/info/?', WorkersInfoHandler),
-            (r'/worker/([a-z0-9-]*)/(alive|dead)/?', WorkerHandler),
             (r'/worker/([a-z0-9-]*)/(start|complete)/?', WorkerStateHandler),
             (r'/page/([a-z0-9-]*)/review/([a-z0-9-]*)/?', ReviewHandler),
             (r'/page/([a-z0-9-]*)/reviews/?', PageReviewsHandler),
@@ -96,11 +94,6 @@ class HolmesApiServer(Server):
             (r'/domains/?', DomainsHandler),
             (r'/domains-details/?', DomainsFullDataHandler),
             (r'/domains/([^/]+)/?', DomainDetailsHandler),
-            (r'/domains/([^/]+)/page-count/?', DomainPageCountHandler),
-            (r'/domains/([^/]+)/review-count/?', DomainReviewCountHandler),
-            (r'/domains/([^/]+)/violation-count/?', DomainViolationCountHandler),
-            (r'/domains/([^/]+)/error-percentage/?', DomainErrorPercentageHandler),
-            (r'/domains/([^/]+)/response-time-avg/?', DomainResponseTimeAvgHandler),
             (r'/domains/([^/]+)/violations-per-day/?', DomainViolationsPerDayHandler),
             (r'/domains/([^/]+)/violations/?', DomainGroupedViolationsHandler),
             (r'/domains/([^/]+)/violations/([0-9]+)/?', DomainTopCategoryViolationsHandler),
